@@ -146,7 +146,7 @@ mlt_producer producer_pango_init( const char *filename )
 			( *strrchr( markup, '.' ) ) = '\0';
 			while ( strchr( markup, '~' ) )
 				( *strchr( markup, '~' ) ) = '\n';
-			mlt_properties_set( properties, "resource", ( char * )filename );
+			mlt_properties_set( properties, "resource", filename );
 			mlt_properties_set( properties, "markup", markup );
 			free( copy );
 		}
@@ -156,7 +156,7 @@ mlt_producer producer_pango_init( const char *filename )
 			mlt_properties contents = mlt_properties_load( filename );
 			mlt_geometry key_frames = mlt_geometry_init( );
 			struct mlt_geometry_item_s item;
-			mlt_properties_set( properties, "resource", ( char * )filename );
+			mlt_properties_set( properties, "resource", filename );
 			mlt_properties_set_data( properties, "contents", contents, 0, ( mlt_destructor )mlt_properties_close, NULL );
 			mlt_properties_set_data( properties, "key_frames", key_frames, 0, ( mlt_destructor )mlt_geometry_close, NULL );
 
@@ -202,8 +202,8 @@ mlt_producer producer_pango_init( const char *filename )
 				if ( markup[ strlen( markup ) - 1 ] == '\n' ) 
 					markup[ strlen( markup ) - 1 ] = '\0';
 
-				mlt_properties_set( properties, "resource", ( char * ) filename );
-				mlt_properties_set( properties, "markup", ( char * ) ( markup == NULL ? "" : markup ) );
+				mlt_properties_set( properties, "resource", filename );
+				mlt_properties_set( properties, "markup", ( markup == NULL ? "" : markup ) );
 				free( markup );
 			}
 			else
@@ -218,7 +218,7 @@ mlt_producer producer_pango_init( const char *filename )
 	return NULL;
 }
 
-static void set_string( char **string, char *value, char *fallback )
+static void set_string( char **string, const char *value, const char *fallback )
 {
 	if ( value != NULL )
 	{
@@ -282,7 +282,7 @@ rgba_color parse_color( char *color )
 
 /** Convert a string property to UTF-8
 */
-static int iconv_utf8( mlt_properties properties, char *prop_name, const char* encoding )
+static int iconv_utf8( mlt_properties properties, const char *prop_name, const char* encoding )
 {
 	char *text = mlt_properties_get( properties, prop_name );
 	int result = -1;
