@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "producer_sdl_image.h"
+#include <framework/mlt_producer.h>
 #include <framework/mlt_frame.h>
 #include <framework/mlt_pool.h>
 
@@ -87,7 +87,7 @@ static int producer_get_image( mlt_frame frame, uint8_t **image, mlt_image_forma
 	return 0;
 }
 
-static int filter_files( struct dirent *de )
+static int filter_files( const struct dirent *de )
 {
 	return de->d_name[ 0 ] != '.';
 }
@@ -150,23 +150,28 @@ static SDL_Surface *load_image( mlt_producer producer )
 		mlt_properties_set_data( properties, "_surface", surface, 0, ( mlt_destructor )SDL_FreeSurface, 0 );
 	}
 
-	image_idx = ( int )floor( ( double )position / ttl ) % mlt_properties_count( filenames );
-	this_resource = mlt_properties_get_value( filenames, image_idx );
-
-	if ( last_resource == NULL || strcmp( last_resource, this_resource ) )
+	if ( mlt_properties_count( filenames ) ) 
 	{
-		surface = IMG_Load( this_resource );
-		if ( surface != NULL )
+		image_idx = ( int )floor( ( double )position / ttl ) % mlt_properties_count( filenames );
+		this_resource = mlt_properties_get_value( filenames, image_idx );
+
+		if ( surface == NULL || last_resource == NULL || strcmp( last_resource, this_resource ) )
+		{
+			surface = IMG_Load( this_resource );
+			if ( surface != NULL )
+			{
+				surface->refcount ++;
+				mlt_properties_set_data( properties, "_surface", surface, 0, ( mlt_destructor )SDL_FreeSurface, 0 );
+				mlt_properties_set( properties, "_last_resource", this_resource );
+				mlt_properties_set_int( properties, "_real_width", surface->w );
+				mlt_properties_set_int( properties, "_real_height", surface->h );
+			}
+		}
+		else if ( surface != NULL )
 		{
 			surface->refcount ++;
-			mlt_properties_set_data( properties, "_surface", surface, 0, ( mlt_destructor )SDL_FreeSurface, 0 );
-			mlt_properties_set( properties, "_last_resource", this_resource );
 		}
 	}
-	else if ( surface != NULL )
-	{
-		surface->refcount ++;
-	}
 
 	return surface;
 }
@@ -174,7 +179,7 @@ static SDL_Surface *load_image( mlt_producer producer )
 static int producer_get_frame( mlt_producer producer, mlt_frame_ptr frame, int index )
 {
 	// Generate a frame
-	*frame = mlt_frame_init( );
+	*frame = mlt_frame_init( MLT_PRODUCER_SERVICE( producer ) );
 
 	if ( *frame != NULL )
 	{
@@ -217,7 +222,7 @@ static void producer_close( mlt_producer producer )
 	free( producer );
 }
 
-mlt_producer producer_sdl_image_init( char *file )
+mlt_producer producer_sdl_image_init( mlt_profile profile, mlt_service_type type, const char *id, char *file )
 {
 	mlt_producer producer = calloc( 1, sizeof( struct mlt_producer_s ) );
 	if ( producer != NULL && mlt_producer_init( producer, NULL ) == 0 )
@@ -236,6 +241,18 @@ mlt_producer producer_sdl_image_init( char *file )
 		mlt_properties_set_int( properties, "ttl", 25 );
 		mlt_properties_set_int( properties, "progressive", 1 );
 		
+		// Validate the resource
+		SDL_Surface *surface = NULL;
+		if ( file && ( surface = load_image( producer ) ) )
+		{
+			SDL_FreeSurface( surface );
+			mlt_properties_set_data( properties, "_surface", NULL, 0, NULL, NULL );
+		}
+		else
+		{
+			producer_close( producer );
+			producer = NULL;
+		}
 		return producer;
 	}
 	free( producer );
